@@ -9,7 +9,7 @@ use HTML::Entities;
 use Scalar::Util qw/blessed/;
 use MRO::Compat;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 __PACKAGE__->mk_accessors('_stacktrace');
 
@@ -308,6 +308,12 @@ code was used.
 
 =head1 COPYRIGHT
 
+Copyright (c) 2005 - 2009
+the Catalyst::Plugin::StackTrace L</AUTHORS>
+as listed above.
+
+=head1 LICENSE
+
 This program is free software, you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
